@@ -6,10 +6,12 @@ import pep8
 
 from flake8 import __version__
 from flake8.reporter import multiprocessing, BaseQReport, QueueReport
-from flake8.util import OrderedSet
+from flake8.util import OrderedSet, is_windows, is_using_stdin
 
 _flake8_noqa = re.compile(r'flake8[:=]\s*noqa', re.I).search
 
+EXTRA_EXCLUDE = '.tox'
+
 
 def _register_extensions():
     """Register all the extensions."""
@@ -33,6 +35,19 @@ def _register_extensions():
     return extensions, parser_hooks, options_hooks
 
 
+def _install_hook_cb(option, option_str, value, parser):
+    # For now, there's no way to affect a change in how pep8 processes
+    # options. If no args are provided and there's no config file present,
+    # it will error out because no input was provided. To get around this,
+    # when we're using --install-hook, we'll say that there were arguments so
+    # we can actually attempt to install the hook.
+    # See: https://gitlab.com/pycqa/flake8/issues/2 and
+    # https://github.com/jcrocholl/pep8/blob/4c5bf00cb613be617c7f48d3b2b82a1c7b895ac1/pep8.py#L1912
+    # for more context.
+    parser.values.install_hook = True
+    parser.rargs.append('.')
+
+
 def get_parser():
     """This returns an instance of optparse.OptionParser with all the
     extensions registered and options set. This wraps ``pep8.get_parser``.
@@ -57,15 +72,16 @@ def get_parser():
         parser.config_options.append('jobs')
         parser.add_option('-j', '--jobs', type='string', default='auto',
                           help="number of jobs to run simultaneously, "
-                          "or 'auto'")
+                          "or 'auto'. This is ignored on Windows.")
 
     parser.add_option('--exit-zero', action='store_true',
                       help="exit with code 0 even if there are errors")
     for parser_hook in parser_hooks:
         parser_hook(parser)
-    parser.add_option('--install-hook', default=False, action='store_true',
+    # See comment above regarding why this has to be a callback.
+    parser.add_option('--install-hook', default=False, dest='install_hook',
                       help='Install the appropriate hook for this '
-                      'repository.', dest='install_hook')
+                      'repository.', action='callback', callback=_install_hook_cb)
     return parser, options_hooks
 
 
@@ -89,10 +105,24 @@ def get_style_guide(**kwargs):
     kwargs['parser'], options_hooks = get_parser()
     styleguide = StyleGuide(**kwargs)
     options = styleguide.options
+
+    if options.exclude and not isinstance(options.exclude, list):
+        options.exclude = pep8.normalize_paths(options.exclude)
+    elif not options.exclude:
+        options.exclude = []
+
+    # Add pattersn in EXTRA_EXCLUDE to the list of excluded patterns
+    options.exclude.extend(pep8.normalize_paths(EXTRA_EXCLUDE))
+
     for options_hook in options_hooks:
         options_hook(options)
 
-    if multiprocessing and options.jobs:
+    if options.diff:
+        options.jobs = None
+
+    force_disable_jobs = is_windows() or is_using_stdin(styleguide.paths)
+
+    if multiprocessing and options.jobs and not force_disable_jobs:
         if options.jobs.isdigit():
             n_jobs = int(options.jobs)
         else:
